@@ -20,12 +20,15 @@ ASSIGN_NAME_XPATH = 'descendant-or-self::Assign/value/Name'
 def get_subscript_name_value(assign_subscript_el):
     """
     Looking for:
-    people[0] (list)
-    capitals['NZ'] (dict)
+    people[0] (list) as in `name = people[0]`
+    capitals['NZ'] (dict) as in `name = capitals['NZ']`
     """
     name_value_el = assign_subscript_el.xpath('value/Name')[0]
     name_value_name = name_value_el.get('id')
-    slice_dets = ast_funcs.get_slice_dets(assign_subscript_el)
+    try:
+        slice_dets = ast_funcs.get_slice_dets(assign_subscript_el)
+    except Exception:
+        return None
     name_value = f"{name_value_name}{slice_dets}"
     return name_value
 
@@ -50,6 +53,7 @@ def pairs_dets_from_el(name2name_el):
         raise Exception("Unable to identify name for name-value assignment. "
             f"Orig error: {e}")
 
+    ## If there is a subscript there might have been assignment to a dict or list
     assign_subscript_els = ancestor_assign_el.xpath(ASSIGN_SUBSCRIPT_XPATH)
     if assign_subscript_els:
         assign_subscript_el = assign_subscript_els[0]
@@ -85,8 +89,12 @@ def pairs_dets_from_block(block_el):
         return None
     pairs_dets = []
     for el in name2name_els:
-        el_pairs_dets = pairs_dets_from_el(el)
-        pairs_dets.extend(el_pairs_dets)
+        try:
+            el_pairs_dets = pairs_dets_from_el(el)
+        except Exception:
+            continue
+        else:
+            pairs_dets.extend(el_pairs_dets)
     return pairs_dets
 
 @all_blocks_help()
@@ -381,19 +389,19 @@ def unpythonic_name_check(block_dets, *, repeat=False):
     Check names used for use of reserved words and camel case.
     """
     names = get_all_names(block_dets, include_non_standard=False)
-    reserved_names = []
-    bad_names = []
-    dubious_names = []
+    reserved_names = set()
+    bad_names = set()
+    dubious_names = set()
     for name in names:
         if is_reserved_name(name):
-            reserved_names.append(name)
+            reserved_names.add(name)
         all_lower_case = (name.lower() == name)
         all_upper_case = (name.upper() == name)
         bad_name = not (all_lower_case or all_upper_case)
         if bad_name:
-            bad_names.append(name)
+            bad_names.add(name)
         elif all_upper_case:
-            dubious_names.append(name)
+            dubious_names.add(name)
     if not (reserved_names or bad_names or dubious_names):
         return None
 
@@ -404,14 +412,15 @@ def unpythonic_name_check(block_dets, *, repeat=False):
     """)
     if reserved_names:
         reserved_names_listed = gen_utils.get_nice_str_list(
-            reserved_names, quoter='`')
+            sorted(reserved_names), quoter='`')
         reserved_comment = layout(f"""\
         Reserved name(s): {reserved_names_listed}
         """)
     else:
         reserved_comment = ''
     if bad_names:
-        bad_names_listed = gen_utils.get_nice_str_list(bad_names, quoter='`')
+        bad_names_listed = gen_utils.get_nice_str_list(
+            sorted(bad_names), quoter='`')
         bad_comment = layout(f"""\
         Un-pythonic name(s): {bad_names_listed}
         """)
@@ -419,7 +428,7 @@ def unpythonic_name_check(block_dets, *, repeat=False):
         bad_comment = ''
     if dubious_names:
         dubious_names_listed = gen_utils.get_nice_str_list(
-            dubious_names, quoter='`')
+            sorted(dubious_names), quoter='`')
         dubious_comment = layout(f"""\
         Possibly un-pythonic name(s): {dubious_names_listed}
         """)
